@@ -34,7 +34,7 @@ import logging
 import time
 from typing import TypeVar, Any, Type
 
-from klyqa_ctl.general.parameters import get_description_parser
+from .general.parameters import get_description_parser
 
 
 NoneType: Type[None] = type(None)
@@ -64,12 +64,6 @@ except:
 
 from typing import TypeVar
 
-
-s: str = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S,%f")[:-3]
-
-print(f"{s} start")
-
-
 tcp_udp_port_lock: AsyncIOLock = AsyncIOLock.instance()
 
 
@@ -296,11 +290,19 @@ class Klyqa_account:
         pass
 
     async def search_and_send_to_device(
-        self, timeout_ms=DEFAULT_SEND_TIMEOUT_MS
+        self, proc_timeout_secs=DEFAULT_COM_PROC_TIMEOUT_SECS
     ) -> bool:
-        """Send broadcast and make tasks for incoming tcp connections."""
+        """! Send broadcast and make tasks for incoming tcp connections.
+        
+        @params:
+            proc_timeout_secs:   max timeout in seconds for a device communication handle process
+            
+        @return:
+            true:  on success
+            false: on exception or error
+        """
         loop = asyncio.get_event_loop()
-
+        
         try:
             if not self.data_communicator.tcp or not self.data_communicator.udp:
                 await self.data_communicator.bind_ports()
@@ -453,7 +455,7 @@ class Klyqa_account:
                                 # timeout task for the device tcp task
                                 loop.create_task(
                                     asyncio.wait_for(
-                                        new_task, timeout=(timeout_ms / 1000)
+                                        new_task, timeout=proc_timeout_secs
                                     )
                                 )
 
@@ -497,7 +499,7 @@ class Klyqa_account:
                                 )
                         else:
                             if datetime.datetime.now() - started > datetime.timedelta(
-                                milliseconds=int(timeout_ms * 1000)
+                                seconds=proc_timeout_secs
                             ):
                                 task.cancel()
                             tasks_undone_new.append((task, started))
@@ -1386,6 +1388,12 @@ class Klyqa_account:
             loop = asyncio.get_event_loop()
 
             send_started: datetime.datetime = datetime.datetime.now()
+            
+            add_command_args_ch = {
+                DeviceType.lighting.name: add_command_args_bulb,
+                DeviceType.cleaner.name: add_command_args_cleaner
+            }
+            add_command_args = add_command_args_ch[args.type]
 
             if args.dev:
                 args.local = True
@@ -1873,7 +1881,7 @@ class Klyqa_account:
                     success = True
 
             if success and scene:
-                scene_start_args: list[str] = ["--routine_id", "0", "--routine_start"]
+                scene_start_args: list[str] = [args.type, "--routine_id", "0", "--routine_start"]
 
                 orginal_args_parser = get_description_parser()
                 scene_start_args_parser: ArgumentParser = get_description_parser()
@@ -2070,6 +2078,10 @@ def main():
         sys.exit(1)
 
     args_parsed = parser.parse_args(args=args_in)
+    
+    if args_parsed.version:
+        print(KLYQA_CTL_VERSION)
+        sys.exit(0)
 
     if not args_parsed:
         sys.exit(1)
@@ -2080,7 +2092,7 @@ def main():
 
     timeout_ms = DEFAULT_SEND_TIMEOUT_MS
     if args_parsed.timeout:
-        timeout_ms = int(args_parsed.timeout[0])
+        timeout_ms = int(args_parsed.timeout[0])*1000
 
     server_ip = args_parsed.myip[0] if args_parsed.myip else "0.0.0.0"
     data_communicator: Data_communicator = Data_communicator(server_ip)
